atupa-core
Foundational types, configuration, and domain models shared across the entire Atupa workspace.
Modules
| Module | Contents |
|---|---|
vm | VmKind — identifies the source Virtual Machine |
gas | GasCategory — classifies execution steps by cost driver |
types | TraceStep, CollapsedStack, HotPath, Profile, ProfileBuilder |
diff | ProtocolDiffReport, DiffRow — protocol-level regression comparison |
config | [AtupaConfig] — multi-source configuration loading |
Re-exports
All public types are re-exported from the crate root so that downstream
crates can use atupa_core::TraceStep etc. without knowing the module layout.
Re-exports
pub use diff::DiffRow;pub use diff::ProtocolDiffReport;pub use gas::GasCategory;pub use types::CollapsedStack;pub use types::HotPath;pub use types::Profile;pub use types::ProfileBuilder;pub use types::TraceStep;pub use vm::ParseVmKindError;pub use vm::VmKind;
Modules
- config
AtupaConfig— runtime configuration with multi-source merging and validation.- diff
- Protocol diff structures:
ProtocolDiffReportandDiffRow. - gas
GasCategory— logical cost-driver classification for execution steps.- types
- Core execution trace types:
TraceStep,CollapsedStack,HotPath,Profile, and theProfileBuilder. - vm
VmKind— identifies which Virtual Machine produced a set of execution steps.