pub struct DiffRow {
pub metric: String,
pub base: f64,
pub target: f64,
pub delta: f64,
pub pct: f64,
pub higher_is_worse: bool,
}Expand description
A single comparable metric between a base and target execution.
Fields
metric: StringHuman-readable metric name (e.g. "Total Gas").
base: f64Metric value for the base transaction.
target: f64Metric value for the target transaction.
delta: f64Absolute difference: target - base.
pct: f64Percentage change relative to the base: delta / base * 100.
Returns 0.0 when base is 0 to avoid division by zero.
higher_is_worse: boolWhen true, an increase in this metric is a regression (e.g. gas cost, read count).
When false, a decrease in this metric is a regression.
Implementations
Sourceimpl DiffRow
impl DiffRow
Sourcepub fn new(metric: &str, base: f64, target: f64, higher_is_worse: bool) -> Self
pub fn new(metric: &str, base: f64, target: f64, higher_is_worse: bool) -> Self
Construct a new DiffRow, automatically computing delta and pct.
use atupa_core::DiffRow;
let row = DiffRow::new("Total Gas", 1_000.0, 1_200.0, true);
assert_eq!(row.delta, 200.0);
assert_eq!(row.pct, 20.0);
assert!(row.is_regression());Sourcepub fn is_regression(&self) -> bool
pub fn is_regression(&self) -> bool
Returns true if this metric has regressed (moved in the undesired direction).
higher_is_worse = true→ regression whendelta > 0(cost increased).higher_is_worse = false→ regression whendelta < 0(a desirable metric decreased).
Sourcepub fn is_improvement(&self) -> bool
pub fn is_improvement(&self) -> bool
Returns true if this metric has improved relative to the baseline.
Sourcepub fn is_neutral(&self) -> bool
pub fn is_neutral(&self) -> bool
Returns true if the metric value is unchanged between base and target.